@@ -5,10 +5,12 @@ import cPickle
 
 from gargoyle_launcher_gui import *
 
-CURRENTVERSION = "0.1.1"
+CURRENTVERSION = "0.1.2"
 
 class GLaunch(QtGui.QMainWindow):
-    def __init__(self, argv, parent=None):
+    games_dict = {}
+
+    def __init__(self, parent=None):
         #build parent user interface
         QtGui.QWidget.__init__(self, parent)
         self.closeOnExit = True
@@ -22,13 +24,7 @@ class GLaunch(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.pushButtonLaunch, QtCore.SIGNAL('clicked()'), self.doLaunch)
 
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
-
-
-        try:                                
-            self.ui.lineEditPath.setText(sys.argv[1])
-        except:          
-            print "no arguments"
-            self.load_settings()
+        self.load_settings()
         
         if(self.closeOnExit):
             self.ui.checkBoxShutdown.setCheckState(QtCore.Qt.Checked)
@@ -39,27 +35,25 @@ class GLaunch(QtGui.QMainWindow):
     def doBrowse(self):
         self.fileName = QtGui.QFileDialog.getOpenFileName(self, "Open", self.ui.lineEditPath.text(), "All Files (*)")
         self.ui.lineEditPath.setText(self.fileName)
+        self.baseName = QtCore.QFileInfo(self.fileName).baseName()
 
     def doLaunch(self):
-#        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle " + str(self.ui.lineEditPath.text()) + " &")
-#        self.settings.setValue("last_path", self.ui.lineEditPath.text())
-#        self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
-        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle " 
-                        + str(self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()) 
-                        + " &")
+        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle \"" 
+                    + str(self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()]) 
+                    + "\" &")
+
         if(self.ui.checkBoxShutdown.isChecked()):
             self.close()
 
 
     def doAddGame(self):
-        add = 1
-        for i in range(self.ui.listWidgetGames.count()): #let's not create duplicates, so lets do a search.
-            if self.ui.listWidgetGames.item(i).text() == self.ui.lineEditPath.text():
-                add = 0
-        if add: #Okay, it wasn't found.  Let's add it.
-            self.ui.listWidgetGames.addItem(self.ui.lineEditPath.text())
+        print self.baseName
+        if not self.baseName in self.games_dict:
+            self.games_dict[self.baseName] = self.fileName
+            self.ui.listWidgetGames.addItem(self.baseName)
 
     def doDelGame(self):
+        del self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()]
         self.ui.listWidgetGames.takeItem(self.ui.listWidgetGames.currentRow())
 
     def setup_settings(self):
@@ -73,11 +67,10 @@ class GLaunch(QtGui.QMainWindow):
         try:
             self.ui.lineEditPath.setText(str(self.settings.value("last_path").toString()))
             self.closeOnExit = self.settings.value("close_on_exit").toBool()
-            print str(self.settings.value("last_path").toString())
 
-            games_list = cPickle.loads(str(self.settings.value("games_list").toString()))
-            for path in games_list:
-                 self.ui.listWidgetGames.addItem(path)
+            self.games_dict = cPickle.loads(str(self.settings.value("games_dict").toString()))
+            for names in self.games_dict:
+                 self.ui.listWidgetGames.addItem(names)
             
 
         except:
@@ -90,15 +83,11 @@ class GLaunch(QtGui.QMainWindow):
         self.settings.setValue("last_path", self.ui.lineEditPath.text())
         self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
         
-        items = []
-        for index in xrange(self.ui.listWidgetGames.count()):
-            items.append(self.ui.listWidgetGames.item(index).text())
-
-        saveData = cPickle.dumps(items)
-        self.settings.setValue("games_list", saveData)
+        saveData = cPickle.dumps(self.games_dict)
+        self.settings.setValue("games_dict", saveData)
 
     def showAbout(self):
-        aboutString = "Gargoyle Launcher: v" + CURRENTVERSION + "\nGirish Gopi (maemo@gman.me.uk)\nSimple Gui to act as a frontend for Gargoyle, the Interactive Fiction Player (http://ccxvii.net/gargoyle/)"
+        aboutString = "Gargoyle Launcher: v" + CURRENTVERSION + "\nGirish Gopi (maemo@gman.me.uk)\nSimple Gui to act as a frontend for Gargoyle, the Interactive Fiction Player (http://ccxvii.net/gargoyle/)\nMany thanks to tkatchev for the Gargoyle port"
         QtGui.QMessageBox.information(self, "About Gargoyle Launch", aboutString)
 
 
@@ -108,7 +97,7 @@ if __name__ == "__main__":
     # We instantiate a QApplication passing the arguments of the script to it:
     app = QtGui.QApplication(sys.argv)
 
-    glaunch = GLaunch(sys.argv[1:])
+    glaunch = GLaunch()
     glaunch.show()
 
     # Now we can start it.
